@@ -1,3 +1,4 @@
+from collections import defaultdict
 from enum import Enum
 from pathlib import Path
 from typing import Type, Dict, Any, Generator, Union
@@ -30,8 +31,8 @@ SKOSOptionsModel = SKOSOptions.__pydantic_model__
 
 
 class SKOSKnowledgeParser(KnowledgeParserBase):
-    def parse(self, source : Path, options: Union[BaseModel, Dict[str, Any]], bar : Bar) -> Generator[Term, None, None]:
-        options = SKOSOptionsModel(**options) if isinstance(options, dict) else options
+    def parse(self, source : Path, options: Union[KnowledgeParserOptions, Dict[str, Any]], bar : Bar) -> Generator[Term, None, None]:
+        options = SKOSOptions(**options) if isinstance(options, dict) else options
         bar.max = 20
         bar.start()
         g = Graph()
@@ -44,13 +45,14 @@ class SKOSKnowledgeParser(KnowledgeParserBase):
             concept: Term = None
             for prefLabel in c.objects(SKOS.prefLabel):
                 if prefLabel.language.startswith(options.lang):
-                    concept: Term = Term(identifier=str(curi), prefLabel=prefLabel.value)
+                    concept: Term = Term(identifier=str(curi), preferredForm=prefLabel.value)
             if concept:
+                props = defaultdict(list)
                 for altLabel in c.objects(SKOS.altLabel):
                     if altLabel.language.startswith(options.lang):
-                        if concept.altLabel is None:
-                            concept.altLabel = []
-                        concept.altLabel.append(altLabel.value)
+                        props['altForms'].append(altLabel.value)
+                if props:
+                    concept.properties = props
                 yield concept
         bar.finish()
 
