@@ -14,9 +14,9 @@ def test_xml():
     assert len(concepts) == 1
     c0 : Term = concepts[0]
     assert c0.identifier == 'http://skos.um.es/unescothes/C02796'
-    assert c0.prefLabel == 'Occupations'
-    assert len(c0.altLabel) == 4
-    assert set(c0.altLabel) == set(['Professional occupations', 'Jobs', 'Careers', 'Professions'])
+    assert c0.preferredForm == 'Occupations'
+    assert len(c0.properties['altForms']) == 4
+    assert set(c0.properties['altForms']) == set(['Professional occupations', 'Jobs', 'Careers', 'Professions'])
 
 
 def test_n3():
@@ -27,9 +27,9 @@ def test_n3():
     assert len(concepts) == 1
     c0 : Term = concepts[0]
     assert c0.identifier == 'http://skos.um.es/unescothes/C02796'
-    assert c0.prefLabel == 'Occupations'
-    assert len(c0.altLabel) == 4
-    assert set(c0.altLabel) == set(['Professional occupations', 'Jobs', 'Careers', 'Professions'])
+    assert c0.preferredForm == 'Occupations'
+    assert len(c0.properties['altForms']) == 4
+    assert set(c0.properties['altForms']) == set(['Professional occupations', 'Jobs', 'Careers', 'Professions'])
 
 
 def test_nt():
@@ -40,9 +40,9 @@ def test_nt():
     assert len(concepts) == 1
     c0 : Term = concepts[0]
     assert c0.identifier == 'http://skos.um.es/unescothes/C02796'
-    assert c0.prefLabel == 'Occupations'
-    assert len(c0.altLabel) == 4
-    assert set(c0.altLabel) == set(['Professional occupations', 'Jobs', 'Careers', 'Professions'])
+    assert c0.preferredForm == 'Occupations'
+    assert len(c0.properties['altForms']) == 4
+    assert set(c0.properties['altForms']) == set(['Professional occupations', 'Jobs', 'Careers', 'Professions'])
 
 def test_jsonld():
     source = Path('data/test.jsonld')
@@ -52,6 +52,6 @@ def test_jsonld():
     assert len(concepts) == 1
     c0 : Term = concepts[0]
     assert c0.identifier == 'http://skos.um.es/unescothes/C02796'
-    assert c0.prefLabel == 'Occupations'
-    assert len(c0.altLabel) == 4
-    assert set(c0.altLabel) == set(['Professional occupations', 'Jobs', 'Careers', 'Professions'])
\ No newline at end of file
+    assert c0.preferredForm == 'Occupations'
+    assert len(c0.properties['altForms']) == 4
+    assert set(c0.properties['altForms']) == set(['Professional occupations', 'Jobs', 'Careers', 'Professions'])
\ No newline at end of file
